@@ -1,14 +1,10 @@
-# -*- coding: utf8 -*-
 from dateutil.parser import parse
 from plone.app.querystring.interfaces import IParsedQueryIndexModifier
 from zope.interface import implementer
 
 
-import six
-
-
 @implementer(IParsedQueryIndexModifier)
-class Subject(object):
+class Subject:
 
     """
     The Subject field in Plone currently uses a utf-8 encoded string.
@@ -22,19 +18,18 @@ class Subject(object):
     """
 
     def __call__(self, value):
-        if not six.PY2:
-            return ('Subject', value)
+        return ("Subject", value)
 
         # Get the query operator
         op = None
-        if 'query' in value:
-            op = 'query'
-        elif 'not' in value:
-            op = 'not'
+        if "query" in value:
+            op = "query"
+        elif "not" in value:
+            op = "not"
 
         query = value[op]
         # query can be a unicode string or a list of unicode strings.
-        if isinstance(query, six.text_type):
+        if isinstance(query, str):
             query = query.encode("utf-8")
         elif isinstance(query, list):
             # We do not want to change the collections' own query string,
@@ -44,31 +39,27 @@ class Subject(object):
             # unicode strings
             i = 0
             for item in copy_of_query:
-                if isinstance(item, six.text_type):
+                if isinstance(item, str):
                     copy_of_query[i] = item.encode("utf-8")
                 i += 1
             query = copy_of_query
         else:
             pass
         value[op] = query
-        return ('Subject', value)
+        return ("Subject", value)
 
 
 @implementer(IParsedQueryIndexModifier)
-class base(object):
+class base:
     """DateIndex query modifier
     see Products.PluginIndexes.DateIndex.DateIndex.DateIndex._convert function
     """
 
     def __call__(self, value):
-
         def _normalize(val):
-            """Encode value, parse dates.
-            """
-            if six.PY2 and isinstance(val, six.text_type):
-                val = val.encode("utf-8")
+            """Encode value, parse dates."""
 
-            if isinstance(val, six.string_types):
+            if isinstance(val, str):
                 try:
                     val = parse(val)
                 except (ValueError, AttributeError):
@@ -76,7 +67,7 @@ class base(object):
 
             return val
 
-        query = value['query']
+        query = value["query"]
         query = _normalize(query)
 
         if isinstance(query, list):
@@ -85,7 +76,7 @@ class base(object):
                 aux.append(_normalize(item))
             query = aux
 
-        value['query'] = query
+        value["query"] = query
         return (self.__class__.__name__, value)
 
 
