@@ -1,24 +1,22 @@
-# -*- coding: utf-8 -*-
 from Acquisition import aq_parent
 from collections import namedtuple
-from DateTime.interfaces import DateTimeError
 from DateTime import DateTime
+from DateTime.interfaces import DateTimeError
 from plone.app.layout.navigation.root import getNavigationRoot
+from plone.base.interfaces import IPloneSiteRoot
+from plone.base.utils import base_hasattr
 from plone.registry.interfaces import IRegistry
 from plone.uuid.interfaces import IUUID
 from Products.CMFCore.utils import getToolByName
-from Products.CMFPlone.interfaces import IPloneSiteRoot
-from Products.CMFPlone.utils import base_hasattr
 from zope.component import getUtility
 from zope.dottedname.resolve import resolve
 
 
-Row = namedtuple('Row', ['index', 'operator', 'values'])
-PATH_INDICES = {'path'}
+Row = namedtuple("Row", ["index", "operator", "values"])
+PATH_INDICES = {"path"}
 
 
 def parseFormquery(context, formquery, sort_on=None, sort_order=None):
-
     if not formquery:
         return {}
     reg = getUtility(IRegistry)
@@ -28,14 +26,14 @@ def parseFormquery(context, formquery, sort_on=None, sort_order=None):
 
     query = {}
     for row in formquery:
-        operator = row.get('o', None)
+        operator = row.get("o", None)
         function_path = reg["%s.operation" % operator]
 
         # The functions expect this pattern of object, so lets give it to
         # them in a named tuple instead of jamming things onto the request
-        row = Row(index=row.get('i', None),
-                  operator=function_path,
-                  values=row.get('v', None))
+        row = Row(
+            index=row.get("i", None), operator=function_path, values=row.get("v", None)
+        )
 
         kwargs = {}
         parser = resolve(row.operator)
@@ -46,7 +44,7 @@ def parseFormquery(context, formquery, sort_on=None, sort_order=None):
         if len(path_index) == 1:
             path_index = list(path_index)[0]
             if path_index in query:
-                query[path_index]['query'].extend(kwargs[path_index]['query'])
+                query[path_index]["query"].extend(kwargs[path_index]["query"])
             else:
                 query.update(kwargs)
         elif len(path_index) > 1:
@@ -60,27 +58,32 @@ def parseFormquery(context, formquery, sort_on=None, sort_order=None):
 
     # Add sorting (sort_on and sort_order) to the query
     if sort_on:
-        catalog = getToolByName(context, 'portal_catalog')
+        catalog = getToolByName(context, "portal_catalog")
         # I get crazy sort_ons like '194' or 'null'.
         if sort_on in catalog.indexes():
-            query['sort_on'] = sort_on
+            query["sort_on"] = sort_on
             if sort_order:
-                query['sort_order'] = sort_order
+                query["sort_order"] = sort_order
     return query
 
 
 # Query operators
 
+
 def _contains(context, row):
     return _equal(context, row)
 
 
+def _excludes(context, row):
+    return {row.index: {"not": row.values}}
+
+
 def _equal(context, row):
-    return {row.index: {'query': row.values, }}
+    return {row.index: {"query": row.values}}
 
 
 def _all(context, row):
-    return {row.index: {'query': row.values, 'operator': 'and'}}
+    return {row.index: {"query": row.values, "operator": "and"}}
 
 
 def _intEqual(context, row):
@@ -95,39 +98,39 @@ def _intEqual(context, row):
             values = int(row.values)
         except (ValueError, TypeError, AttributeError):
             pass
-    return {row.index: {'query': values, }}
+    return {row.index: {"query": values}}
 
 
 def _isTrue(context, row):
-    return {row.index: {'query': True, }}
+    return {row.index: {"query": True}}
 
 
 def _isFalse(context, row):
-    return {row.index: {'query': False, }}
+    return {row.index: {"query": False}}
 
 
 def _between(context, row):
     if not row.values:
-        val = ['', '']
+        val = ["", ""]
     else:
         val = row.values
 
-    tmp = {row.index:
-           {
-               'query': sorted(val),
-               'range': 'minmax',
-           },
-           }
+    tmp = {
+        row.index: {
+            "query": sorted(val),
+            "range": "minmax",
+        },
+    }
     return tmp
 
 
 def _largerThan(context, row):
-    tmp = {row.index:
-           {
-               'query': row.values,
-               'range': 'min',
-           },
-           }
+    tmp = {
+        row.index: {
+            "query": row.values,
+            "range": "min",
+        },
+    }
     return tmp
 
 
@@ -138,22 +141,22 @@ def _intLargerThan(context, row):
             value = int(row.values)
         except (ValueError, TypeError, AttributeError):
             pass
-    tmp = {row.index:
-           {
-               'query': value,
-               'range': 'min',
-           },
-           }
+    tmp = {
+        row.index: {
+            "query": value,
+            "range": "min",
+        },
+    }
     return tmp
 
 
 def _lessThan(context, row):
-    tmp = {row.index:
-           {
-               'query': row.values,
-               'range': 'max',
-           },
-           }
+    tmp = {
+        row.index: {
+            "query": row.values,
+            "range": "max",
+        },
+    }
     return tmp
 
 
@@ -165,27 +168,27 @@ def _intLessThan(context, row):
         except (ValueError, TypeError, AttributeError):
             # value = 0
             pass
-    tmp = {row.index:
-           {
-               'query': value,
-               'range': 'max',
-           },
-           }
+    tmp = {
+        row.index: {
+            "query": value,
+            "range": "max",
+        },
+    }
     return tmp
 
 
 def _currentUser(context, row):
     """Current user lookup"""
-    mt = getToolByName(context, 'portal_membership')
+    mt = getToolByName(context, "portal_membership")
     user = mt.getAuthenticatedMember()
-    return {row.index: {'query': user.getUserName()}}
+    return {row.index: {"query": user.getUserName()}}
 
 
 def _showInactive(context, row):
-    """ Current user roles lookup in order to determine whether user should
-        be allowed to view inactive content
+    """Current user roles lookup in order to determine whether user should
+    be allowed to view inactive content
     """
-    mt = getToolByName(context, 'portal_membership')
+    mt = getToolByName(context, "portal_membership")
     user = mt.getAuthenticatedMember()
     value = False
     user_roles = user.getRoles()
@@ -209,9 +212,7 @@ def _lessThanRelativeDate(context, row):
     start_date = now.earliestTime()
     end_date = now + values
     end_date = end_date.latestTime()
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=(start_date, end_date))
+    row = Row(index=row.index, operator=row.operator, values=(start_date, end_date))
     return _between(context, row)
 
 
@@ -226,9 +227,7 @@ def _moreThanRelativeDate(context, row):
     start_date = now - values
     start_date = start_date.earliestTime()
     end_date = now.latestTime()
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=(start_date, end_date))
+    row = Row(index=row.index, operator=row.operator, values=(start_date, end_date))
     return _between(context, row)
 
 
@@ -240,14 +239,10 @@ def _betweenDates(context, row):
     try:
         end_date = DateTime(row.values[1])
     except DateTimeError:
-        row = Row(index=row.index,
-                  operator=row.operator,
-                  values=start_date)
+        row = Row(index=row.index, operator=row.operator, values=start_date)
         return _largerThan(context, row)
     else:
-        row = Row(index=row.index,
-                  operator=row.operator,
-                  values=(start_date, end_date))
+        row = Row(index=row.index, operator=row.operator, values=(start_date, end_date))
 
         return _between(context, row)
 
@@ -256,23 +251,17 @@ def _today(context, row):
     now = DateTime()
     start_date = now.earliestTime()
     end_date = now.latestTime()
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=(start_date, end_date))
+    row = Row(index=row.index, operator=row.operator, values=(start_date, end_date))
     return _between(context, row)
 
 
 def _afterToday(context, row):
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=DateTime())
+    row = Row(index=row.index, operator=row.operator, values=DateTime())
     return _largerThan(context, row)
 
 
 def _beforeToday(context, row):
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=DateTime())
+    row = Row(index=row.index, operator=row.operator, values=DateTime())
     return _lessThan(context, row)
 
 
@@ -281,9 +270,11 @@ def _beforeRelativeDate(context, row):
         values = int(row.values)
     except ValueError:
         values = 0
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=DateTime().earliestTime() - values)
+    row = Row(
+        index=row.index,
+        operator=row.operator,
+        values=DateTime().earliestTime() - values,
+    )
     return _lessThan(context, row)
 
 
@@ -292,41 +283,43 @@ def _afterRelativeDate(context, row):
         values = int(row.values)
     except ValueError:
         values = 0
-    row = Row(index=row.index,
-              operator=row.operator,
-              values=DateTime().earliestTime() + values)
+    row = Row(
+        index=row.index,
+        operator=row.operator,
+        values=DateTime().earliestTime() + values,
+    )
     return _largerThan(context, row)
 
 
 def _pathByRoot(root, context, row):
     values = row.values
     depth = None
-    if '::' in values:
-        values, _depth = values.split('::', 1)
+    if "::" in values:
+        values, _depth = values.split("::", 1)
         try:
             depth = int(_depth)
         except ValueError:
             pass
-    if '/' not in values:
+    if "/" not in values:
         # It must be a UID
         values = getPathByUID(context, values)
     # take care of absolute paths without root
-    if not values.startswith(root + '/') and values != root:
+    if not values.startswith(root + "/") and values != root:
         values = root + values
     query = {}
     if depth is not None:
-        query['depth'] = depth
+        query["depth"] = depth
         # when a depth value is specified, a trailing slash matters on the
         # query
-        values = values.rstrip('/')
-    query['query'] = [values]
+        values = values.rstrip("/")
+    query["query"] = [values]
     return {row.index: query}
 
 
 def _absolutePath(context, row):
-    portal_url = getToolByName(context, 'portal_url')
+    portal_url = getToolByName(context, "portal_url")
     portal = portal_url.getPortalObject()
-    root = '/'.join(portal.getPhysicalPath())
+    root = "/".join(portal.getPhysicalPath())
     return _pathByRoot(root, context, row)
 
 
@@ -339,10 +332,10 @@ def _relativePath(context, row):
     obj = context
     values = row.values
     depthstr = ""
-    if '::' in values:
-        values, _depth = values.split('::', 1)
+    if "::" in values:
+        values, _depth = values.split("::", 1)
         depthstr = "::%s" % _depth
-    for x in [r for r in values.split('/') if r]:
+    for x in [r for r in values.split("/") if r]:
         if x == "..":
             if IPloneSiteRoot.providedBy(obj):
                 break
@@ -355,9 +348,11 @@ def _relativePath(context, row):
                 if child and base_hasattr(child, "getPhysicalPath"):
                     obj = child
 
-    row = Row(index=row.index,
-              operator=row.operator,
-              values='/'.join(obj.getPhysicalPath()) + depthstr)
+    row = Row(
+        index=row.index,
+        operator=row.operator,
+        values="/".join(obj.getPhysicalPath()) + depthstr,
+    )
 
     return _absolutePath(context, row)
 
@@ -371,18 +366,18 @@ def _referenceIs(context, row):
         return {}
 
     # clear possible depth string
-    values = values.split('::')[0]
+    values = values.split("::")[0]
 
-    if '/' not in values:
+    if "/" not in values:
         return {row.index: values}
 
     pquery = _absolutePath(context, row)
     if not pquery:
         return {}
     # use resolved path here...
-    path = pquery[row.index]['query']
+    path = pquery[row.index]["query"]
 
-    portal_url = getToolByName(context, 'portal_url')
+    portal_url = getToolByName(context, "portal_url")
     portal = portal_url.getPortalObject()
 
     if type(path) == list:
@@ -397,10 +392,11 @@ def _referenceIs(context, row):
 
 # Helper functions
 
+
 def getPathByUID(context, uid):
     """Returns the path of an object specified by UID"""
-    catalog = getToolByName(context, 'portal_catalog')
+    catalog = getToolByName(context, "portal_catalog")
     brains = catalog.unrestrictedSearchResults(dict(UID=uid))
     if brains:
         return brains[0].getPath()
-    return ''
+    return ""
